import { B as BUILD, c as consoleDevInfo, H, d as doc, N as NAMESPACE, p as promiseResolve, b as bootstrapLazy } from './index-ec6d8311.js';
export { s as setNonce } from './index-ec6d8311.js';
import { g as globalScripts } from './app-globals-0f993ce5.js';

/*
 Stencil Client Patch Browser v4.3.0 | MIT Licensed | https://stenciljs.com
 */
const patchBrowser = () => {
    // NOTE!! This fn cannot use async/await!
    if (BUILD.isDev && !BUILD.isTesting) {
        consoleDevInfo('Running in development mode.');
    }
    if (BUILD.cloneNodeFix) {
        // opted-in to polyfill cloneNode() for slot polyfilled components
        patchCloneNodeFix(H.prototype);
    }
    if (BUILD.profile && !performance.mark) {
        // not all browsers support performance.mark/measure (Safari 10)
        // because the mark/measure APIs are designed to write entries to a buffer in the browser that does not exist,
        // simply stub the implementations out.
        // TODO(STENCIL-323): Remove this patch when support for older browsers is removed (breaking)
        // @ts-ignore
        performance.mark = performance.measure = () => {
            /*noop*/
        };
        performance.getEntriesByName = () => [];
    }
    // @ts-ignore
    const scriptElm = BUILD.scriptDataOpts
        ? Array.from(doc.querySelectorAll('script')).find((s) => new RegExp(`\/${NAMESPACE}(\\.esm)?\\.js($|\\?|#)`).test(s.src) ||
            s.getAttribute('data-stencil-namespace') === NAMESPACE)
        : null;
    const importMeta = import.meta.url;
    const opts = BUILD.scriptDataOpts ? (scriptElm || {})['data-opts'] || {} : {};
    if (importMeta !== '') {
        opts.resourcesUrl = new URL('.', importMeta).href;
    }
    return promiseResolve(opts);
};
const patchCloneNodeFix = (HTMLElementPrototype) => {
    const nativeCloneNodeFn = HTMLElementPrototype.cloneNode;
    HTMLElementPrototype.cloneNode = function (deep) {
        if (this.nodeName === 'TEMPLATE') {
            return nativeCloneNodeFn.call(this, deep);
        }
        const clonedNode = nativeCloneNodeFn.call(this, false);
        const srcChildNodes = this.childNodes;
        if (deep) {
            for (let i = 0; i < srcChildNodes.length; i++) {
                // Node.ATTRIBUTE_NODE === 2, and checking because IE11
                if (srcChildNodes[i].nodeType !== 2) {
                    clonedNode.appendChild(srcChildNodes[i].cloneNode(true));
                }
            }
        }
        return clonedNode;
    };
};

patchBrowser().then(options => {
  globalScripts();
  return bootstrapLazy([["nk-drop-mint-winter-button",[[1,"nk-drop-mint-winter-button",{"projectId":[1,"project-id"],"successTitle":[1,"success-title"],"successMessage":[1,"success-message"],"disabled":[32],"loading":[32],"saleActive":[32],"presaleActive":[32],"isOpen":[32],"dialogOpen":[32],"extraMintParams":[32],"openModal":[64]}]]],["nk-drop-mint-button",[[1,"nk-drop-mint-button",{"successTitle":[1,"success-title"],"successMessage":[1,"success-message"],"disabled":[32],"loading":[32],"supply":[32],"maxAmount":[32],"maxPerMint":[32],"price":[32],"saleActive":[32],"presaleActive":[32],"selections":[32],"dialogOpen":[32],"selectedValue":[32],"mint":[64]}]]],["nk-drop-mint-crossmint-button",[[1,"nk-drop-mint-crossmint-button",{"projectId":[1,"project-id"],"collectionId":[1,"collection-id"],"successTitle":[1,"success-title"],"successMessage":[1,"success-message"],"disabled":[32],"loading":[32],"mintTo":[32],"saleActive":[32],"presaleActive":[32],"isOpen":[32],"dialogOpen":[32],"mintConfig":[32],"openModal":[64]}]]],["nk-edition-mint-button",[[1,"nk-edition-mint-button",{"editionId":[2,"edition-id"],"successTitle":[1,"success-title"],"successMessage":[1,"success-message"],"disabled":[32],"loading":[32],"quantity":[32],"maxQuantity":[32],"maxPerWallet":[32],"maxPerMint":[32],"price":[32],"active":[32],"selections":[32],"dialogOpen":[32],"selectedValue":[32],"mint":[64]}]]],["nk-edition-mint-crossmint-button",[[1,"nk-edition-mint-crossmint-button",{"projectId":[1,"project-id"],"collectionId":[1,"collection-id"],"editionId":[2,"edition-id"],"successTitle":[1,"success-title"],"successMessage":[1,"success-message"],"disabled":[32],"loading":[32],"mintTo":[32],"active":[32],"isOpen":[32],"dialogOpen":[32],"mintConfig":[32],"openModal":[64]}]]],["nk-connect-wallet-button",[[1,"nk-connect-wallet-button",{"isConnected":[32],"isWrongNetwork":[32],"address":[32],"ensName":[32]}]]],["nk-diamond",[[1,"nk-diamond",{"collectionId":[1,"collection-id"],"isDev":[4,"is-dev"],"loading":[32]}]]],["nk-drop-price-text",[[1,"nk-drop-price-text",{"price":[32]}]]],["nk-drop-supply-text",[[1,"nk-drop-supply-text",{"supply":[32],"maxAmount":[32]}]]],["nk-edition-price-text",[[1,"nk-edition-price-text",{"editionId":[2,"edition-id"],"price":[32]}]]],["nk-edition-supply-text",[[1,"nk-edition-supply-text",{"editionId":[2,"edition-id"],"quantity":[32],"maxQuantity":[32]}]]],["nk-is-connected",[[1,"nk-is-connected",{"isConnected":[32]}]]],["nk-is-holder",[[1,"nk-is-holder",{"tokenId":[1,"token-id"],"isHolder":[32]}]]],["nk-is-not-connected",[[1,"nk-is-not-connected",{"isNotConnected":[32]}]]],["nk-loading",[[1,"nk-loading"]]],["nk-dialog",[[1,"nk-dialog",{"dialogTitle":[1,"dialog-title"],"open":[4],"buttonText":[1,"button-text"]}]]]], options);
});

//# sourceMappingURL=widgets.esm.js.map